==> huaweicloudsdkfunctiongraph-3.1.72-py2.py3-none-any.whl: huaweicloudsdkfunctiongraph/v2/model/list_function_applications_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListFunctionApplicationsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'applications': 'list[ListFunctionApplicationResult]',
        'next_marker': 'int',
        'count': 'int'
    }

    attribute_map = {
        'applications': 'applications',
        'next_marker': 'next_marker',
        'count': 'count'
    }

    def __init__(self, applications=None, next_marker=None, count=None):
        """ListFunctionApplicationsResponse

        The model defined in huaweicloud sdk

        :param applications: 函数应用列表
        :type applications: list[:class:`huaweicloudsdkfunctiongraph.v2.ListFunctionApplicationResult`]
        :param next_marker: 下次读取位置
        :type next_marker: int
        :param count: 应用程序总数
        :type count: int
        """
        
        super(ListFunctionApplicationsResponse, self).__init__()

        self._applications = None
        self._next_marker = None
        self._count = None
        self.discriminator = None

        if applications is not None:
            self.applications = applications
        if next_marker is not None:
            self.next_marker = next_marker
        if count is not None:
            self.count = count

    @property
    def applications(self):
        """Gets the applications of this ListFunctionApplicationsResponse.

        函数应用列表

        :return: The applications of this ListFunctionApplicationsResponse.
        :rtype: list[:class:`huaweicloudsdkfunctiongraph.v2.ListFunctionApplicationResult`]
        """
        return self._applications

    @applications.setter
    def applications(self, applications):
        """Sets the applications of this ListFunctionApplicationsResponse.

        函数应用列表

        :param applications: The applications of this ListFunctionApplicationsResponse.
        :type applications: list[:class:`huaweicloudsdkfunctiongraph.v2.ListFunctionApplicationResult`]
        """
        self._applications = applications

    @property
    def next_marker(self):
        """Gets the next_marker of this ListFunctionApplicationsResponse.

        下次读取位置

        :return: The next_marker of this ListFunctionApplicationsResponse.
        :rtype: int
        """
        return self._next_marker

    @next_marker.setter
    def next_marker(self, next_marker):
        """Sets the next_marker of this ListFunctionApplicationsResponse.

        下次读取位置

        :param next_marker: The next_marker of this ListFunctionApplicationsResponse.
        :type next_marker: int
        """
        self._next_marker = next_marker

    @property
    def count(self):
        """Gets the count of this ListFunctionApplicationsResponse.

        应用程序总数

        :return: The count of this ListFunctionApplicationsResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this ListFunctionApplicationsResponse.

        应用程序总数

        :param count: The count of this ListFunctionApplicationsResponse.
        :type count: int
        """
        self._count = count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListFunctionApplicationsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkfunctiongraph-3.1.158-py2.py3-none-any.whl: huaweicloudsdkfunctiongraph/v2/model/list_function_applications_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListFunctionApplicationsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'applications': 'list[ListFunctionApplicationResult]',
        'next_marker': 'int',
        'count': 'int'
    }

    attribute_map = {
        'applications': 'applications',
        'next_marker': 'next_marker',
        'count': 'count'
    }

    def __init__(self, applications=None, next_marker=None, count=None):
        r"""ListFunctionApplicationsResponse

        The model defined in huaweicloud sdk

        :param applications: 函数应用列表
        :type applications: list[:class:`huaweicloudsdkfunctiongraph.v2.ListFunctionApplicationResult`]
        :param next_marker: 下次读取位置
        :type next_marker: int
        :param count: 应用程序总数
        :type count: int
        """
        
        super(ListFunctionApplicationsResponse, self).__init__()

        self._applications = None
        self._next_marker = None
        self._count = None
        self.discriminator = None

        if applications is not None:
            self.applications = applications
        if next_marker is not None:
            self.next_marker = next_marker
        if count is not None:
            self.count = count

    @property
    def applications(self):
        r"""Gets the applications of this ListFunctionApplicationsResponse.

        函数应用列表

        :return: The applications of this ListFunctionApplicationsResponse.
        :rtype: list[:class:`huaweicloudsdkfunctiongraph.v2.ListFunctionApplicationResult`]
        """
        return self._applications

    @applications.setter
    def applications(self, applications):
        r"""Sets the applications of this ListFunctionApplicationsResponse.

        函数应用列表

        :param applications: The applications of this ListFunctionApplicationsResponse.
        :type applications: list[:class:`huaweicloudsdkfunctiongraph.v2.ListFunctionApplicationResult`]
        """
        self._applications = applications

    @property
    def next_marker(self):
        r"""Gets the next_marker of this ListFunctionApplicationsResponse.

        下次读取位置

        :return: The next_marker of this ListFunctionApplicationsResponse.
        :rtype: int
        """
        return self._next_marker

    @next_marker.setter
    def next_marker(self, next_marker):
        r"""Sets the next_marker of this ListFunctionApplicationsResponse.

        下次读取位置

        :param next_marker: The next_marker of this ListFunctionApplicationsResponse.
        :type next_marker: int
        """
        self._next_marker = next_marker

    @property
    def count(self):
        r"""Gets the count of this ListFunctionApplicationsResponse.

        应用程序总数

        :return: The count of this ListFunctionApplicationsResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        r"""Sets the count of this ListFunctionApplicationsResponse.

        应用程序总数

        :param count: The count of this ListFunctionApplicationsResponse.
        :type count: int
        """
        self._count = count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListFunctionApplicationsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
